@@ -621,6 +621,9 @@ sub latex {
 \renewcaptionname{[% safe_options.lang %]}{\contentsname}{[% safe_options.mainlanguage_toc_name %]}
 [% END %]
 
+[% IF safe_options.nocoverpage %]
+\let\chapter\section
+[% END %]
 % global style
 [% IF safe_options.headings %]
 \setlength{\headsep}{\baselineskip}
@@ -631,12 +634,12 @@ sub latex {
     \lehead{\pagemark}
     \rohead{\pagemark}
     \rehead{[% doc.header_as_latex.title %]}
-    \lohead{[% doc.header_as_latex.subtitle %]}
+    \lohead{[% IF doc.header_defined.subtitle %][% doc.header_as_latex.subtitle %][% ELSE %][% doc.header_as_latex.title %][% END %]}
     [% END %]
     [% IF safe_options.headings.author_title %]
     \lehead{\pagemark}
     \rohead{\pagemark}
-    \rehead{[% doc.header_as_latex.author %]}
+    \rehead{[% IF doc.header_defined.author %][% doc.header_as_latex.author %][% ELSE %][% doc.header_as_latex.title %][% END %]}
     \lohead{[% doc.header_as_latex.title %]}
     [% END %]
     [% IF safe_options.headings.section_subsection %]
@@ -835,8 +838,12 @@ pdfkeywords={[% tex_metadata.keywords %]}%
 [% IF safe_options.wants_toc %]
 \tableofcontents
 % start a new right-handed page
+[% IF safe_options.nocoverpage %]
+  \vskip 3em
+[% ELSE %]
 \cleardoublepage
 [% END %]
+[% END %]
 
 [% doc.as_latex %]
 
